==> micronaut-http-server-4.2.3-sources.jar: io/micronaut/http/server/cors/CorsUtil.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.http.server.cors;

import io.micronaut.core.annotation.Internal;
import io.micronaut.http.HttpHeaders;
import io.micronaut.http.HttpMethod;
import io.micronaut.http.HttpRequest;

import java.util.Optional;

import static io.micronaut.http.HttpHeaders.ACCESS_CONTROL_REQUEST_METHOD;

/**
 * Utility methods for CORS.
 *
 * @author Graeme Rocher
 * @since 1.0
 */
@Internal
public final class CorsUtil {
    private CorsUtil() {

    }

    /**
     * @param request The {@link HttpRequest} object
     * @return Return whether this request is a pre-flight request
     */
    public static boolean isPreflightRequest(HttpRequest<?> request) {
        HttpHeaders headers = request.getHeaders();
        Optional<String> origin = request.getOrigin();
        return origin.isPresent() && headers.contains(ACCESS_CONTROL_REQUEST_METHOD) && HttpMethod.OPTIONS == request.getMethod();
    }
}

==> micronaut-http-server-4.9.12-sources.jar: io/micronaut/http/server/cors/CorsUtil.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.http.server.cors;

import io.micronaut.core.annotation.Internal;
import io.micronaut.http.HttpHeaders;
import io.micronaut.http.HttpMethod;
import io.micronaut.http.HttpRequest;

import java.util.Optional;

import static io.micronaut.http.HttpHeaders.ACCESS_CONTROL_REQUEST_HEADERS;
import static io.micronaut.http.HttpHeaders.ACCESS_CONTROL_REQUEST_METHOD;
import static io.micronaut.http.HttpHeaders.ACCESS_CONTROL_REQUEST_PRIVATE_NETWORK;

/**
 * Utility methods for CORS.
 *
 * @author Graeme Rocher
 * @since 1.0
 */
@Internal
public final class CorsUtil {
    private CorsUtil() {

    }

    /**
     * @param request The {@link HttpRequest} object
     * @return Return whether this request is a pre-flight request
     */
    public static boolean isPreflightRequest(HttpRequest<?> request) {
        HttpHeaders headers = request.getHeaders();
        Optional<String> origin = request.getOrigin();
        return origin.isPresent()
                && HttpMethod.OPTIONS == request.getMethod()
                && (headers.contains(ACCESS_CONTROL_REQUEST_METHOD)
                    || headers.contains(ACCESS_CONTROL_REQUEST_HEADERS)
                    || headers.contains(ACCESS_CONTROL_REQUEST_PRIVATE_NETWORK));
    }
}
